# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`conntrackd`](#conntrackd): This class is able to install or remove conntrackd on a node. It
* [`conntrackd::config`](#conntrackdconfig): This class exists to coordinate all configuration for the conntrackd daemon

#### Private Classes

* `conntrackd::package`: This class exists to coordinate all software package management related
* `conntrackd::service`: This class exists to coordinate all service management related actions,

## Classes

### <a name="conntrackd"></a>`conntrackd`

# conntrackd

manages the status and configuration of the service.

#### Examples

##### Installation, make sure service is running and will be started at boot time:

```puppet
class { 'conntrackd': }
```

##### Removal/decommissioning:

```puppet
class { 'conntrackd':
  ensure => 'absent',
}
```

##### Install everything but disable service(s) afterwards

```puppet
class { 'conntrackd':
  status => 'disabled',
}
```

#### Parameters

The following parameters are available in the `conntrackd` class:

* [`ensure`](#ensure)
* [`autoupgrade`](#autoupgrade)
* [`status`](#status)
* [`package`](#package)
* [`service_name`](#service_name)
* [`service_hasrestart`](#service_hasrestart)
* [`service_hasstatus`](#service_hasstatus)
* [`service_pattern`](#service_pattern)
* [`service_status`](#service_status)
* [`config_dir`](#config_dir)
* [`config_filename`](#config_filename)
* [`nice`](#nice)
* [`hashsize`](#hashsize)
* [`logfile`](#logfile)
* [`syslog`](#syslog)
* [`lockfile`](#lockfile)
* [`sock_path`](#sock_path)
* [`sock_backlog`](#sock_backlog)
* [`ignore_ips_ipv4`](#ignore_ips_ipv4)
* [`ignore_ips_ipv6`](#ignore_ips_ipv6)
* [`tcp_flows`](#tcp_flows)
* [`netlinkbuffersize`](#netlinkbuffersize)
* [`netlinkbuffersizemaxgrowth`](#netlinkbuffersizemaxgrowth)
* [`netlinkoverrunresync`](#netlinkoverrunresync)
* [`netlinkeventsreliable`](#netlinkeventsreliable)
* [`pollsecs`](#pollsecs)
* [`eventiterationlimit`](#eventiterationlimit)
* [`sync_mode`](#sync_mode)
* [`resend_queue_size`](#resend_queue_size)
* [`ack_window_size`](#ack_window_size)
* [`disable_external_cache`](#disable_external_cache)
* [`disable_internal_cache`](#disable_internal_cache)
* [`refresh_time`](#refresh_time)
* [`cache_timeout`](#cache_timeout)
* [`commit_timeout`](#commit_timeout)
* [`purge_timeout`](#purge_timeout)
* [`protocol`](#protocol)
* [`interface`](#interface)
* [`ipv4_address`](#ipv4_address)
* [`ipv4_interface`](#ipv4_interface)
* [`mcast_group`](#mcast_group)
* [`sndsocketbuffer`](#sndsocketbuffer)
* [`rcvsocketbuffer`](#rcvsocketbuffer)
* [`checksum`](#checksum)
* [`udp_ipv6_address`](#udp_ipv6_address)
* [`udp_ipv4_dest`](#udp_ipv4_dest)
* [`udp_ipv6_dest`](#udp_ipv6_dest)
* [`udp_port`](#udp_port)
* [`filter_accept_protocols`](#filter_accept_protocols)
* [`tcp_window_tracking`](#tcp_window_tracking)
* [`track_tcp_states`](#track_tcp_states)
* [`scheduler_type`](#scheduler_type)
* [`scheduler_priority`](#scheduler_priority)
* [`stats_logfile`](#stats_logfile)
* [`stats_netlink_reliable`](#stats_netlink_reliable)
* [`stats_syslog`](#stats_syslog)
* [`hashlimit`](#hashlimit)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

String. Controls if the managed resources shall be <tt>present</tt> or
<tt>absent</tt>. If set to <tt>absent</tt>:
* The managed software packages are being uninstalled.
* Any traces of the packages will be purged as good as possible. This may
  include existing configuration files. The exact behavior is provider
  dependent. Q.v.:
  * Puppet type reference: {package, "purgeable"}[http://j.mp/xbxmNP]
  * {Puppet's package provider source code}[http://j.mp/wtVCaL]
* System modifications (if any) will be reverted as good as possible
  (e.g. removal of created users, services, changed log settings, ...).
* This is thus destructive and should be used with care.
Defaults to <tt>present</tt>.

##### <a name="autoupgrade"></a>`autoupgrade`

Data type: `Boolean`

Boolean. If set to <tt>true</tt>, any managed package gets upgraded
on each Puppet run when the package provider is able to find a newer
version than the present one. The exact behavior is provider dependent.
Q.v.:
* Puppet type reference: {package, "upgradeable"}[http://j.mp/xbxmNP]
* {Puppet's package provider source code}[http://j.mp/wtVCaL]
Defaults to <tt>false</tt>.

##### <a name="status"></a>`status`

Data type: `Enum[
    'enabled',
    'disabled',
    'running',
    'unmanaged'
  ]`

String to define the status of the service. Possible values:
* <tt>enabled</tt>: Service is running and will be started at boot time.
* <tt>disabled</tt>: Service is stopped and will not be started at boot
  time.
* <tt>running</tt>: Service is running but will not be started at boot time.
  You can use this to start a service on the first Puppet run instead of
  the system startup.
* <tt>unmanaged</tt>: Service will not be started at boot time and Puppet
  does not care whether the service is running or not. For example, this may
  be useful if a cluster management software is used to decide when to start
  the service plus assuring it is running on the desired node.
Defaults to <tt>enabled</tt>. The singular form ("service") is used for the
sake of convenience. Of course, the defined status affects all services if
more than one is managed (see <tt>service.pp</tt> to check if this is the
case).

##### <a name="package"></a>`package`

Data type: `Array`

The name(s) of the conntrack package(s)

##### <a name="service_name"></a>`service_name`

Data type: `String`

The name of the conntrackd service

##### <a name="service_hasrestart"></a>`service_hasrestart`

Data type: `Boolean`

The service `hasrestart` attribute

##### <a name="service_hasstatus"></a>`service_hasstatus`

Data type: `Boolean`

The service `hasstatus` attribute

##### <a name="service_pattern"></a>`service_pattern`

Data type: `String`

The service `pattern` attribute

##### <a name="service_status"></a>`service_status`

Data type: `String`

The service `status` attribute

##### <a name="config_dir"></a>`config_dir`

Data type: `String`

Top-level directory for configuration

##### <a name="config_filename"></a>`config_filename`

Data type: `String`

Config file name

##### <a name="nice"></a>`nice`

Data type: `Integer[-20,19]`

integer: Nice value of the conntrackd process
range: <tt>-19</tt> to <tt>+19</tt>
Default: <tt>-1</tt>

##### <a name="hashsize"></a>`hashsize`

Data type: `Integer`

integer: Number of buckets in the cache hashtable.
Default: <tt>32768</tt>

##### <a name="logfile"></a>`logfile`

Data type: `String`

string:  fully qualified path to the logfile or 'Off'
         (directory must exist and be writable)
values:  <tt>on</tt>, <tt>off</tt>, <tt><path to file></tt>
Default: <tt>off</tt>

##### <a name="syslog"></a>`syslog`

Data type: `String`

string:  enable syslog logging
values:  <tt>on</tt>, <tt>off</tt> or <tt><syslog facility></tt>
Default: <tt>on</tt>

##### <a name="lockfile"></a>`lockfile`

Data type: `String`

string:  fully qualified path to the lockfile
Default: <tt>/var/lock/conntrack.lock</tt>

##### <a name="sock_path"></a>`sock_path`

Data type: `String`

string:  fully qualified path to the UNIX socket used for configuration
Default: <tt>/var/run/conntrackd.ctl</tt>

##### <a name="sock_backlog"></a>`sock_backlog`

Data type: `Integer`

integer: sets the blacklog ofr the UNIX socket
Default: <tt>20</tt>

##### <a name="ignore_ips_ipv4"></a>`ignore_ips_ipv4`

Data type: `Array`

array:   list of IPv4 addresses to ignore.
         should include this node's address
Default: <tt>[ '127.0.0.1', '192.168.0.1', '10.1.1.1' ]</tt>

##### <a name="ignore_ips_ipv6"></a>`ignore_ips_ipv6`

Data type: `Array`

array:   list of IPv4 addresses to ignore.
         should include this node's address
Default: <tt>[ '::1' ]</tt>

##### <a name="tcp_flows"></a>`tcp_flows`

Data type: `Array`

array:   list of flows to monitor
allowed: 'ESTABLISHED', 'CLOSED', 'TIME_WAIT', 'CLOSE_WAIT'
Default: <tt>[ 'ESTABLISHED', 'CLOSED', 'TIME_WAIT', 'CLOSE_WAIT' ]</tt>

##### <a name="netlinkbuffersize"></a>`netlinkbuffersize`

Data type: `Integer`

integer: Netlink event socket buffer size
Default: <tt>2097152</tt>

##### <a name="netlinkbuffersizemaxgrowth"></a>`netlinkbuffersizemaxgrowth`

Data type: `Integer`

integer: The daemon doubles the size of the netlink event socket buffer size
         if it detects netlink event message dropping . This clause sets the
         maximum buffer size growth that can be reached.
Default: <tt>8388608</tt>

##### <a name="netlinkoverrunresync"></a>`netlinkoverrunresync`

Data type: `String`

boolean: If the daemon detects that Netlink is dropping state-change events,
         it automatically schedules a resynchronization against the Kernel
         after 30 seconds (default value)
Default: <tt>on</tt>

##### <a name="netlinkeventsreliable"></a>`netlinkeventsreliable`

Data type: `String`

boolean: If you want reliable event reporting over Netlink, set on this
         option. If you set on this clause, it is a good idea to set off
         NetlinkOverrunResync.
Default: <tt>Off</tt>

##### <a name="pollsecs"></a>`pollsecs`

Data type: `Optional[Integer]`

integer: By default, the daemon receives state updates following an
         event-driven model. You can modify this behaviour by switching to
         polling mode with the PollSecs clause.
Default: <tt>Off</tt>

##### <a name="eventiterationlimit"></a>`eventiterationlimit`

Data type: `Integer`

integer: The daemon prioritizes the handling of state-change events coming
         from the core. With this clause, you can set the maximum number of
         state-change events (coming from kernel-space) that the daemon
         will handle after which it will handle other events coming from the
         network or userspace
Default: <tt>100</tt>

##### <a name="sync_mode"></a>`sync_mode`

Data type: `Enum['FTFW', 'NOTRACK', 'ALARM']`

string:  The syncronisation mode to use
values:  one of: <tt>FTFW</tt>, <tt>NOTRACK</tt> or <tt>ALARM</tt>
Default: <tt>FTFW</tt>

##### <a name="resend_queue_size"></a>`resend_queue_size`

Data type: `Integer`

integer: Size of the resend queue (in objects)
Default: <tt>131072</tt>

##### <a name="ack_window_size"></a>`ack_window_size`

Data type: `Integer`

integer: acknowledgement window size. If you decrease this
         value, the number of acknowlegdments increases
Default: <tt>300</tt>

##### <a name="disable_external_cache"></a>`disable_external_cache`

Data type: `String`

boolean: This clause allows you to disable the external cache. Thus,
         the state entries are directly injected into the kernel
         conntrack table.
Default: <tt>Off</tt>

##### <a name="disable_internal_cache"></a>`disable_internal_cache`

Data type: `String`

boolean: This clause allows you to disable the internal cache.
Default: <tt>Off</tt>

##### <a name="refresh_time"></a>`refresh_time`

Data type: `Integer`

integer: ALARM Mode: If a conntrack entry is not modified in <= 15 seconds,
         then a message is broadcasted.
Default: <tt>15</tt>

##### <a name="cache_timeout"></a>`cache_timeout`

Data type: `Integer`

integer: If we don't receive a notification about the state of
         an entry in the external cache after N seconds, then
         remove it.
Default: <tt>180</tt>

##### <a name="commit_timeout"></a>`commit_timeout`

Data type: `Integer`

integer: This parameter allows you to set an initial fixed timeout
         for the committed entries when this node goes from backup
         to primary.
Default: <tt>180</tt>

##### <a name="purge_timeout"></a>`purge_timeout`

Data type: `Integer`

integer: If the firewall replica goes from primary to backup,
         the conntrackd -t command is invoked in the script.
         This command schedules a flush of the table in N seconds.
Default: <tt>60</tt>

##### <a name="protocol"></a>`protocol`

Data type: `Enum['Multicast', 'UDP']`

string:  The protocol to use for syncing.
values:  <tt>Multicast</tt> or <tt>UDP</tt>
Default: <tt>Multicast</tt>

##### <a name="interface"></a>`interface`

Data type: `String`

string:  Dedicated physical interface for communicating with the other host.
value:   <tt><interface name></tt>
Default: <tt>undef</tt>

##### <a name="ipv4_address"></a>`ipv4_address`

Data type: `String`

string:  Multicast mode only: The multicast address to commuincate over
value:   *Must* be set for Multicast mode: <tt><multicast address></tt>
Default: <tt>255.0.0.50</tt>

##### <a name="ipv4_interface"></a>`ipv4_interface`

Data type: `String`

string:  The ip address to bind to for multicast and UDP connections.
value:   *Must* be set for Multicast or UDP mode: <tt><ipaddress></tt>
Default: <tt>undef</tt>

##### <a name="mcast_group"></a>`mcast_group`

Data type: `String`

integer: The multicast group to use for Multicast mode
Default: <tt>3780</tt>

##### <a name="sndsocketbuffer"></a>`sndsocketbuffer`

Data type: `Integer`

integer: The multicast sender uses a buffer to enqueue the packets
         that are going to be transmitted.
Default: <tt>1249280</tt>

##### <a name="rcvsocketbuffer"></a>`rcvsocketbuffer`

Data type: `Integer`

integer: The multicast receiver uses a buffer to enqueue the packets
         that the socket is pending to handle.
Default: <tt>1249280</tt>

##### <a name="checksum"></a>`checksum`

Data type: `String`

integer: Enable/Disable message checksumming.
Default: <tt>on</tt>

##### <a name="udp_ipv6_address"></a>`udp_ipv6_address`

Data type: `Optional[String]`

string:  The IPv6 interface address to bind to in UDP mode
Default: <tt>undef</tt>

##### <a name="udp_ipv4_dest"></a>`udp_ipv4_dest`

Data type: `Optional[String]`

string:  The IPv4 interface of the other node when UDP is enabled
Default: <tt>undef</tt>

##### <a name="udp_ipv6_dest"></a>`udp_ipv6_dest`

Data type: `Optional[String]`

string:  The IPv6 interface of the other node when UDP is enabled
Default: <tt>undef</tt>

##### <a name="udp_port"></a>`udp_port`

Data type: `Integer`

integer: The UDP port to communicate over (should be the same on both nodes)
Default: <tt>3780</tt>

##### <a name="filter_accept_protocols"></a>`filter_accept_protocols`

Data type: `Array`

array:   Accept only certain protocols
values:  <tt>TCP</tt>, <tt>SCTP</tt>, <tt>DCCP</tt>,
         <tt>UDP</tt>, <tt>ICMP</tt>, <tt>IPv6-ICMP</tt>
Default: <tt>[ 'TCP', 'SCTP', 'DCCP' ]</tt>

##### <a name="tcp_window_tracking"></a>`tcp_window_tracking`

Data type: `String`

boolean: TCP state-entries have window tracking disabled by default,
         you can enable it with this option.
Default: <tt>Off</tt>

##### <a name="track_tcp_states"></a>`track_tcp_states`

Data type: `Array`

array:   The specific TCP states to sync
Default: <tt>[ 'ESTABLISHED', 'CLOSED', 'TIME_WAIT', 'CLOSE_WAIT' ]</tt>

##### <a name="scheduler_type"></a>`scheduler_type`

Data type: `String`

string:  Select a different scheduler for the daemon.
         See man sched_setscheduler(2) for more information. Using a RT
         scheduler reduces the chances to overrun the Netlink buffer.
values:  <tt>RR</tt>, <tt>FIFO</tt>
Default: <tt>FIFO</tt>

##### <a name="scheduler_priority"></a>`scheduler_priority`

Data type: `String`

integer: scheduler process priority
range:   <tt>0</tt> - <tt>99</tt>
Default: <tt>99</tt>

##### <a name="stats_logfile"></a>`stats_logfile`

Data type: `Optional[String]`

string:  enable logging of stastics to a file
values:  fully qualified path to the statis logfile or 'Off'
Default: <tt>undef</tt>

##### <a name="stats_netlink_reliable"></a>`stats_netlink_reliable`

Data type: `String`

boolean: If you want reliable event reporting over Netlink, set on this
         option. If you set on this clause, it is a good idea to set off
         NetlinkOverrunResync.
Default: <tt>Off</tt>

##### <a name="stats_syslog"></a>`stats_syslog`

Data type: `Optional[String]`

string:  enable syslog logging of statistics
values:  <tt>on</tt>, <tt>off</tt> or <tt><syslog facility></tt>

##### <a name="hashlimit"></a>`hashlimit`

Data type: `Optional[Integer]`

integer: Maximum number of conntracks in table
Default: <tt>2x the value of /proc/sys/net/netfilter/nf_conntrack_max</tt>

Default value: ``undef``

### <a name="conntrackdconfig"></a>`conntrackd::config`

# conntrackd::config

#### Parameters

The following parameters are available in the `conntrackd::config` class:

* [`ensure`](#ensure)
* [`nice`](#nice)
* [`hashsize`](#hashsize)
* [`hashlimit`](#hashlimit)
* [`logfile`](#logfile)
* [`syslog`](#syslog)
* [`lockfile`](#lockfile)
* [`sock_path`](#sock_path)
* [`sock_backlog`](#sock_backlog)
* [`ignore_ips_ipv4`](#ignore_ips_ipv4)
* [`ignore_ips_ipv6`](#ignore_ips_ipv6)
* [`tcp_flows`](#tcp_flows)
* [`netlinkbuffersize`](#netlinkbuffersize)
* [`netlinkbuffersizemaxgrowth`](#netlinkbuffersizemaxgrowth)
* [`netlinkoverrunresync`](#netlinkoverrunresync)
* [`netlinkeventsreliable`](#netlinkeventsreliable)
* [`pollsecs`](#pollsecs)
* [`eventiterationlimit`](#eventiterationlimit)
* [`sync_mode`](#sync_mode)
* [`resend_queue_size`](#resend_queue_size)
* [`ack_window_size`](#ack_window_size)
* [`disable_external_cache`](#disable_external_cache)
* [`disable_internal_cache`](#disable_internal_cache)
* [`refresh_time`](#refresh_time)
* [`cache_timeout`](#cache_timeout)
* [`commit_timeout`](#commit_timeout)
* [`purge_timeout`](#purge_timeout)
* [`protocol`](#protocol)
* [`interface`](#interface)
* [`ipv4_address`](#ipv4_address)
* [`ipv4_interface`](#ipv4_interface)
* [`mcast_group`](#mcast_group)
* [`sndsocketbuffer`](#sndsocketbuffer)
* [`rcvsocketbuffer`](#rcvsocketbuffer)
* [`checksum`](#checksum)
* [`udp_ipv6_address`](#udp_ipv6_address)
* [`udp_ipv4_dest`](#udp_ipv4_dest)
* [`udp_ipv6_dest`](#udp_ipv6_dest)
* [`udp_port`](#udp_port)
* [`filter_accept_protocols`](#filter_accept_protocols)
* [`tcp_window_tracking`](#tcp_window_tracking)
* [`track_tcp_states`](#track_tcp_states)
* [`scheduler_type`](#scheduler_type)
* [`scheduler_priority`](#scheduler_priority)
* [`stats_logfile`](#stats_logfile)
* [`stats_netlink_reliable`](#stats_netlink_reliable)
* [`stats_syslog`](#stats_syslog)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

String. Controls if the managed resources shall be <tt>present</tt> or
<tt>absent</tt>.
Default: <tt>present</tt>.

Default value: `$conntrackd::ensure`

##### <a name="nice"></a>`nice`

Data type: `Integer[-20,19]`

integer: Nice value of the conntrackd process
range: <tt>-19</tt> to <tt>+19</tt>
Default: <tt>-1</tt>

Default value: `$conntrackd::nice`

##### <a name="hashsize"></a>`hashsize`

Data type: `Integer`

integer: Number of buckets in the cache hashtable.
Default: <tt>32768</tt>

Default value: `$conntrackd::hashsize`

##### <a name="hashlimit"></a>`hashlimit`

Data type: `Integer`

integer: Maximum number of conntracks in table
Default: <tt>2x the value of /proc/sys/net/netfilter/nf_conntrack_max</tt>

Default value: `$conntrackd::_hashlimit`

##### <a name="logfile"></a>`logfile`

Data type: `String`

string:  fully qualified path to the logfile or 'Off'
         (directory must exist and be writable)
values:  <tt>on</tt>, <tt>off</tt>, <tt><path to file></tt>
Default: <tt>off</tt>

Default value: `$conntrackd::logfile`

##### <a name="syslog"></a>`syslog`

Data type: `String`

string:  enable syslog logging
values:  <tt>on</tt>, <tt>off</tt> or <tt><syslog facility></tt>
Default: <tt>on</tt>

Default value: `$conntrackd::syslog`

##### <a name="lockfile"></a>`lockfile`

Data type: `String`

string:  fully qualified path to the lockfile
Default: <tt>/var/lock/conntrack.lock</tt>

Default value: `$conntrackd::lockfile`

##### <a name="sock_path"></a>`sock_path`

Data type: `String`

string:  fully qualified path to the UNIX socket used for configuration
Default: <tt>/var/run/conntrackd.ctl</tt>

Default value: `$conntrackd::sock_path`

##### <a name="sock_backlog"></a>`sock_backlog`

Data type: `Integer`

integer: sets the blacklog ofr the UNIX socket
Default: <tt>20</tt>

Default value: `$conntrackd::sock_backlog`

##### <a name="ignore_ips_ipv4"></a>`ignore_ips_ipv4`

Data type: `Array`

array:   list of IPv4 addresses to ignore.
         should include this node's address
Default: <tt>[ '127.0.0.1', '192.168.0.1', '10.1.1.1' ]</tt>

Default value: `$conntrackd::ignore_ips_ipv4`

##### <a name="ignore_ips_ipv6"></a>`ignore_ips_ipv6`

Data type: `Array`

array:   list of IPv4 addresses to ignore.
         should include this node's address
Default: <tt>[ '::1' ]</tt>

Default value: `$conntrackd::ignore_ips_ipv6`

##### <a name="tcp_flows"></a>`tcp_flows`

Data type: `Array`

array:   list of flows to monitor
allowed: 'ESTABLISHED', 'CLOSED', 'TIME_WAIT', 'CLOSE_WAIT'
Default: <tt>[ 'ESTABLISHED', 'CLOSED', 'TIME_WAIT', 'CLOSE_WAIT' ]</tt>

Default value: `$conntrackd::tcp_flows`

##### <a name="netlinkbuffersize"></a>`netlinkbuffersize`

Data type: `Integer`

integer: Netlink event socket buffer size
Default: <tt>2097152</tt>

Default value: `$conntrackd::netlinkbuffersize`

##### <a name="netlinkbuffersizemaxgrowth"></a>`netlinkbuffersizemaxgrowth`

Data type: `Integer`

integer: The daemon doubles the size of the netlink event socket buffer size
         if it detects netlink event message dropping . This clause sets the
         maximum buffer size growth that can be reached.
Default: <tt>8388608</tt>

Default value: `$conntrackd::netlinkbuffersizemaxgrowth`

##### <a name="netlinkoverrunresync"></a>`netlinkoverrunresync`

Data type: `String`

boolean: If the daemon detects that Netlink is dropping state-change events,
         it automatically schedules a resynchronization against the Kernel
         after 30 seconds (default value)
Default: <tt>on</tt>

Default value: `$conntrackd::netlinkoverrunresync`

##### <a name="netlinkeventsreliable"></a>`netlinkeventsreliable`

Data type: `String`

boolean: If you want reliable event reporting over Netlink, set on this
         option. If you set on this clause, it is a good idea to set off
         NetlinkOverrunResync.
Default: <tt>Off</tt>

Default value: `$conntrackd::netlinkeventsreliable`

##### <a name="pollsecs"></a>`pollsecs`

Data type: `Optional[Integer]`

integer: By default, the daemon receives state updates following an
         event-driven model. You can modify this behaviour by switching to
         polling mode with the PollSecs clause.
Default: <tt>Off</tt>

Default value: `$conntrackd::pollsecs`

##### <a name="eventiterationlimit"></a>`eventiterationlimit`

Data type: `Integer`

integer: The daemon prioritizes the handling of state-change events coming
         from the core. With this clause, you can set the maximum number of
         state-change events (coming from kernel-space) that the daemon
         will handle after which it will handle other events coming from the
         network or userspace
Default: <tt>100</tt>

Default value: `$conntrackd::eventiterationlimit`

##### <a name="sync_mode"></a>`sync_mode`

Data type: `Enum['FTFW', 'NOTRACK', 'ALARM']`

string:  The syncronisation mode to use
values:  one of: <tt>FTFW</tt>, <tt>NOTRACK</tt> or <tt>ALARM</tt>
Default: <tt>FTFW</tt>

Default value: `$conntrackd::sync_mode`

##### <a name="resend_queue_size"></a>`resend_queue_size`

Data type: `Integer`

integer: Size of the resend queue (in objects)
Default: <tt>131072</tt>

Default value: `$conntrackd::resend_queue_size`

##### <a name="ack_window_size"></a>`ack_window_size`

Data type: `Integer`

integer: acknowledgement window size. If you decrease this
         value, the number of acknowlegdments increases
Default: <tt>300</tt>

Default value: `$conntrackd::ack_window_size`

##### <a name="disable_external_cache"></a>`disable_external_cache`

Data type: `String`

boolean: This clause allows you to disable the external cache. Thus,
         the state entries are directly injected into the kernel
         conntrack table.
Default: <tt>Off</tt>

Default value: `$conntrackd::disable_external_cache`

##### <a name="disable_internal_cache"></a>`disable_internal_cache`

Data type: `String`

boolean: This clause allows you to disable the internal cache.
Default: <tt>Off</tt>

Default value: `$conntrackd::disable_internal_cache`

##### <a name="refresh_time"></a>`refresh_time`

Data type: `Integer`

integer: ALARM Mode: If a conntrack entry is not modified in <= 15 seconds,
         then a message is broadcasted.
Default: <tt>15</tt>

Default value: `$conntrackd::refresh_time`

##### <a name="cache_timeout"></a>`cache_timeout`

Data type: `Integer`

integer: If we don't receive a notification about the state of
         an entry in the external cache after N seconds, then
         remove it.
Default: <tt>180</tt>

Default value: `$conntrackd::cache_timeout`

##### <a name="commit_timeout"></a>`commit_timeout`

Data type: `Integer`

integer: This parameter allows you to set an initial fixed timeout
         for the committed entries when this node goes from backup
         to primary.
Default: <tt>180</tt>

Default value: `$conntrackd::commit_timeout`

##### <a name="purge_timeout"></a>`purge_timeout`

Data type: `Integer`

integer: If the firewall replica goes from primary to backup,
         the conntrackd -t command is invoked in the script.
         This command schedules a flush of the table in N seconds.
Default: <tt>60</tt>

Default value: `$conntrackd::purge_timeout`

##### <a name="protocol"></a>`protocol`

Data type: `Enum['Multicast', 'UDP']`

string:  The protocol to use for syncing.
values:  <tt>Multicast</tt> or <tt>UDP</tt>
Default: <tt>Multicast</tt>

Default value: `$conntrackd::protocol`

##### <a name="interface"></a>`interface`

Data type: `String`

string:  Dedicated physical interface for communicating with the other host.
value:   <tt><interface name></tt>
Default: <tt>undef</tt>

Default value: `$conntrackd::interface`

##### <a name="ipv4_address"></a>`ipv4_address`

Data type: `String`

string:  Multicast mode only: The multicast address to commuincate over
value:   *Must* be set for Multicast mode: <tt><multicast address></tt>
Default: <tt>255.0.0.50</tt>

Default value: `$conntrackd::ipv4_address`

##### <a name="ipv4_interface"></a>`ipv4_interface`

Data type: `String`

string:  The ip address to bind to for multicast and UDP connections.
value:   *Must* be set for Multicast or UDP mode: <tt><ipaddress></tt>
Default: <tt>undef</tt>

Default value: `$conntrackd::ipv4_interface`

##### <a name="mcast_group"></a>`mcast_group`

Data type: `String`

integer: The multicast group to use for Multicast mode
Default: <tt>3780</tt>

Default value: `$conntrackd::mcast_group`

##### <a name="sndsocketbuffer"></a>`sndsocketbuffer`

Data type: `Integer`

integer: The multicast sender uses a buffer to enqueue the packets
         that are going to be transmitted.
Default: <tt>1249280</tt>

Default value: `$conntrackd::sndsocketbuffer`

##### <a name="rcvsocketbuffer"></a>`rcvsocketbuffer`

Data type: `Integer`

integer: The multicast receiver uses a buffer to enqueue the packets
         that the socket is pending to handle.
Default: <tt>1249280</tt>

Default value: `$conntrackd::rcvsocketbuffer`

##### <a name="checksum"></a>`checksum`

Data type: `String`

integer: Enable/Disable message checksumming.
Default: <tt>on</tt>

Default value: `$conntrackd::checksum`

##### <a name="udp_ipv6_address"></a>`udp_ipv6_address`

Data type: `Optional[String]`

string:  The IPv6 interface address to bind to in UDP mode
Default: <tt>undef</tt>

Default value: `$conntrackd::udp_ipv6_address`

##### <a name="udp_ipv4_dest"></a>`udp_ipv4_dest`

Data type: `Optional[String]`

string:  The IPv4 interface of the other node when UDP is enabled
Default: <tt>undef</tt>

Default value: `$conntrackd::udp_ipv4_dest`

##### <a name="udp_ipv6_dest"></a>`udp_ipv6_dest`

Data type: `Optional[String]`

string:  The IPv6 interface of the other node when UDP is enabled
Default: <tt>undef</tt>

Default value: `$conntrackd::udp_ipv6_dest`

##### <a name="udp_port"></a>`udp_port`

Data type: `Integer`

integer: The UDP port to communicate over (should be the same on both nodes)
Default: <tt>3780</tt>

Default value: `$conntrackd::udp_port`

##### <a name="filter_accept_protocols"></a>`filter_accept_protocols`

Data type: `Array`

array:   Accept only certain protocols
values:  <tt>TCP</tt>, <tt>SCTP</tt>, <tt>DCCP</tt>,
         <tt>UDP</tt>, <tt>ICMP</tt>, <tt>IPv6-ICMP</tt>
Default: <tt>[ 'TCP', 'SCTP', 'DCCP' ]</tt>

Default value: `$conntrackd::filter_accept_protocols`

##### <a name="tcp_window_tracking"></a>`tcp_window_tracking`

Data type: `String`

boolean: TCP state-entries have window tracking disabled by default,
         you can enable it with this option.
Default: <tt>Off</tt>

Default value: `$conntrackd::tcp_window_tracking`

##### <a name="track_tcp_states"></a>`track_tcp_states`

Data type: `Array`

array:   The specific TCP states to sync
Default: <tt>[ 'ESTABLISHED', 'CLOSED', 'TIME_WAIT', 'CLOSE_WAIT' ]</tt>

Default value: `$conntrackd::track_tcp_states`

##### <a name="scheduler_type"></a>`scheduler_type`

Data type: `String`

string:  Select a different scheduler for the daemon.
         See man sched_setscheduler(2) for more information. Using a RT
         scheduler reduces the chances to overrun the Netlink buffer.
values:  <tt>RR</tt>, <tt>FIFO</tt>
Default: <tt>FIFO</tt>

Default value: `$conntrackd::scheduler_type`

##### <a name="scheduler_priority"></a>`scheduler_priority`

Data type: `String`

integer: scheduler process priority
range:   <tt>0</tt> - <tt>99</tt>
Default: <tt>99</tt>

Default value: `$conntrackd::scheduler_priority`

##### <a name="stats_logfile"></a>`stats_logfile`

Data type: `Optional[String]`

string:  enable logging of stastics to a file
values:  fully qualified path to the statis logfile or 'Off'
Default: <tt>undef</tt>

Default value: `$conntrackd::stats_logfile`

##### <a name="stats_netlink_reliable"></a>`stats_netlink_reliable`

Data type: `String`

boolean: If you want reliable event reporting over Netlink, set on this
         option. If you set on this clause, it is a good idea to set off
         NetlinkOverrunResync.
Default: <tt>Off</tt>

Default value: `$conntrackd::stats_netlink_reliable`

##### <a name="stats_syslog"></a>`stats_syslog`

Data type: `Optional[String]`

string:  enable syslog logging of statistics
values:  <tt>on</tt>, <tt>off</tt> or <tt><syslog facility></tt>

Default value: `$conntrackd::stats_syslog`

